<?php
/**
 * Plugin CIWIDGET
 * Copyright (c) Christophe IMBERTI
 * Licence Creative commons by-nc-sa
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/widget_commun');
include_spip('inc/video_commun');

function formulaires_ciwidget_dailymotion_charger_dist($objet = '', $id_objet = '', $id_widget = 0, $retour = '') {
    	$id_auteur = isset($GLOBALS['visiteur_session']['id_auteur']) ? $GLOBALS['visiteur_session']['id_auteur'] : 0;

	if (!autoriser('modifier',$objet,$id_objet) AND $id_objet!=(0-$id_auteur))
		return false;

        $valeurs = array(
            'titre'=>'',
            'descriptif'=>'',
            'credits'=>'',
            'url'=>'',
            'playlist'=>ciwidget_lire_meta_cle('dailymotion','playlist_defaut'),
            'duree'=>'00:00:00',
            'largeur'=> ciwidget_lire_meta_cle('dailymotion','largeur_defaut'),
            'hauteur'=>ciwidget_lire_meta_cle('dailymotion','hauteur_defaut'));
        
        $id_widget = intval($id_widget);
	if ($id_widget>0) {
		$result = sql_select("*", "spip_ciwidget", "id_widget=$id_widget");
		while ($row = sql_fetch($result)) { 
			$valeurs = $row;
		}
                
                // anti hack
                if (isset($valeurs['type_widget']) AND $valeurs['type_widget']!='dailymotion'){
                    return false;
                }
                
                // unserialize le champ contenu
                if (isset($valeurs['contenu'])){
                    $contenu = unserialize($valeurs['contenu']);
                    $valeurs['contenu'] = '';
                    if ($contenu AND is_array($contenu)){
                        $valeurs = array_merge($valeurs,$contenu);
                    }
                    if (isset($valeurs['duree'])){
                        $valeurs['duree'] = date('H:i:s', mktime(0, 0, intval($valeurs['duree'])));
                    }
                }
	}

        if (ciwidget_lire_meta_cle('dailymotion','largeur_non_modifiable')=='oui'){
            $valeurs['ci_largeur_non_modifiable']='oui';
            $valeurs['largeur']=ciwidget_lire_meta_cle('dailymotion','largeur_defaut');
        }
        if (ciwidget_lire_meta_cle('dailymotion','hauteur_non_modifiable')=='oui'){
            $valeurs['ci_hauteur_non_modifiable']='oui';
            $valeurs['hauteur']=ciwidget_lire_meta_cle('dailymotion','hauteur_defaut');
        }
        
        $valeurs['api_dailymotion'] = 'non';
        if (!$id_widget AND ciwidget_lire_meta_cle('dailymotion','api_dailymotion')=='oui'){
            $valeurs['api_dailymotion'] = 'oui';
        }
        
        $valeurs['retour_objet'] = ciwidget_retour_vers_objet($objet, $id_objet);

	return $valeurs;
}

function formulaires_ciwidget_dailymotion_verifier_dist($objet = '', $id_objet = '', $id_widget = 0, $retour = '') {
        $erreurs = array();        
        $api_dailymotion = false;
            
        if (!$id_widget AND ciwidget_lire_meta_cle('dailymotion','api_dailymotion')=='oui'){
            $api_dailymotion = true;
        }
        
        if (!$api_dailymotion){
            $titre = _request('titre');	
            if (!$titre){
                    $erreurs['titre'] = _T('info_obligatoire');
            }
        }
        
	$url = _request('url');	
	if (!$url){
		$erreurs['url'] = _T('info_obligatoire');
        } elseif (!ci_dailymotion_fichier($url)) {
		$erreurs['url'] = _T('ciwidget:valeur_incorrecte');
        }

	$playlist = _request('playlist');
        if ($playlist){
            if (!ctype_alnum($playlist)) {
		$erreurs['playlist'] = _T('ciwidget:valeur_incorrecte');
            }
        }
        
	if (ciwidget_erreur_largeur(_request('largeur'))){
            $erreurs['largeur'] = ciwidget_erreur_largeur(_request('largeur'));
        }
        
	if (ciwidget_erreur_hauteur(_request('hauteur'))){
            $erreurs['hauteur'] = ciwidget_erreur_hauteur(_request('hauteur'));
        }	
        
        if (!$api_dailymotion){
            if (ciwidget_erreur_duree(_request('duree'))){
                $erreurs['duree'] = ciwidget_erreur_duree(_request('duree'));
            }	
        }
        
	return $erreurs;
}

function formulaires_ciwidget_dailymotion_traiter_dist($objet = '', $id_objet = '', $id_widget = 0, $retour = '') {
        $id_widget = intval($id_widget);
        $res = array();
        $api_dailymotion = false;
        if (!$id_widget AND ciwidget_lire_meta_cle('dailymotion','api_dailymotion')=='oui'){
            $api_dailymotion = true;
        }

        $c = array();
        if (!$api_dailymotion){
            foreach (array('titre', 'descriptif') as $champ){
                    $c[$champ] = _request($champ);
            }
        }
        
        $url = _request('url');
        $playlist = _request('playlist');
        $largeur = ciwidget_verif_largeur_sinon_defaut(_request('largeur'), ciwidget_lire_meta_cle('dailymotion','largeur_defaut'));
        $hauteur = ciwidget_verif_hauteur_sinon_defaut(_request('hauteur'), ciwidget_lire_meta_cle('dailymotion','hauteur_defaut'));
        $tags = '';
        
        if (!$api_dailymotion){
            if (preg_match('#([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2})#', _request('duree'), $regs)) {
                 $duree = (3600*intval($regs[1])) + (60*intval($regs[2])) + intval($regs[3]);
            }
            $credits = _request('credits');
        } else {
            $duree = 0;
            $credits = '';
        }

	// on tente de récupérer les données api_dailymotion
        if ($api_dailymotion){
            include_spip('inc/ciwidget_inc_dailymotion');
            $id_dailymotion = ci_dailymotion_fichier($url);
            if ($data = ciwidget_api_dailymotion_recuperer_data($id_dailymotion)) {
                if (isset($data['title']) AND $data['title']){
                    $c['titre'] = $data['title'];
                }
                if (isset($data['description']) AND $data['description']){
                    $c['descriptif'] = $data['description'];
                }
                if (isset($data['duration']) AND $data['duration']){
                    $duree = $data['duration'];
                }
                if (isset($data['owner.screenname']) AND $data['owner.screenname']){
                    $credits = $data['owner.screenname'];
                }
                if (isset($data['tag']) AND $data['tag']){
                    $tags = $data['tag'];
                }
            }
        }
        
        $type_widget = 'dailymotion';
        $c['contenu'] = serialize(array('url'=>$url, 'playlist'=>$playlist, 'duree'=>$duree, 'largeur'=>$largeur, 'hauteur'=>$hauteur, 'credits'=>$credits, 'tags'=>$tags));
        $c['type_widget'] = $type_widget;
        $c['objet'] = $objet;
        $c['id_objet'] = $id_objet;
        
	if ($id_widget>0) {
            // modifier
            sql_updateq("spip_ciwidget", $c, "id_widget=$id_widget");
        } else {
            // ajouter
            $id_widget = sql_insertq('spip_ciwidget', $c);
        }
    
        $res = ciwidget_retour_formulaire($objet,$id_objet,$type_widget,$retour);

	return $res;
}

?>