<?php
/**
 * Plugin CIWIDGET
 * Copyright (c) Christophe IMBERTI
 * Licence Creative commons by-nc-sa
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/widget_commun');
include_spip('inc/ciwidget_tmp');
include_spip('inc/ciwidget_graphique');
include_spip('inc/ciwidget_verifier');


function formulaires_ciwidget_graphique8_charger_dist($objet = '', $id_objet = '', $id_widget = 0, $id_widget_tmp = 0, $retour = '') {
    if (!$id_widget_tmp){
            return false;
    }

    $prerenseigner = ciwidget_graphique_id_prerenseigner($id_widget_tmp);    
    
    if ($prerenseigner>0) {
        $valeurs_prerenseigner_contenu = ciwidget_contenu_unserialize($prerenseigner);
        $valeurs_actuelles = ciwidget_valeurs_tmp($id_widget,$id_widget_tmp,'graphique');
        $valeurs = array_merge($valeurs_actuelles,$valeurs_prerenseigner_contenu);
        
        // securite
        $valeurs['id_widget'] = $id_widget;           
        $valeurs['id_widget_tmp'] = $id_widget_tmp;           
    } else {    
        $valeurs = ciwidget_valeurs_tmp($id_widget,$id_widget_tmp,'graphique');
    }
    
    // securite
    if (!isset($valeurs['objet']) OR !isset($valeurs['id_objet']) OR !isset($valeurs['id_auteur']) 
            OR !autoriser('modifier',$valeurs['objet'],$valeurs['id_objet'])
            OR $valeurs['id_auteur']!=$GLOBALS['visiteur_session']['id_auteur']){
            return false;
    }
    
    $champs_prerequis = array(
        'type',
        'titre',
        'serie_colonne',
        'entete_colonne',
        'entete_ligne'
        );
    foreach ($champs_prerequis AS $champ){
        if (!isset($valeurs[$champ]) OR !$valeurs[$champ]){
            return false;
        }
    }

    // valeurs par defaut
    $valeurs_par_defaut = ciwidget_graphique_config_par_defaut();
    foreach ($valeurs_par_defaut AS $cle=>$valeur){
        if (!isset($valeurs[$cle])){
            $valeurs[$cle] = $valeur;
            
            // cas particulier de l'opacite
            if ($cle=='opacite'){
                if (in_array($valeurs['type'],array('bar','horizontalBar','pie','doughnut'))){
                    $valeurs[$cle] = '100';
                }
            }
        }
    }
    
    // cas particulier de la largeur
    $largeur_defaut = ciwidget_lire_meta_cle('graphique','largeur_defaut');
    if (!isset($valeurs['largeur_defaut'])){
        $valeurs['largeur_defaut'] = $largeur_defaut;
    }
    
    // cas particulier du ratio
    $aspectRatio = '';
    if (isset($valeurs['aspect_ratio'])){
        $ci_aspect_ratio = ciwidget_aspect_ratio($valeurs['aspect_ratio'],'graphique');
        if ($ci_aspect_ratio>0){
            $aspectRatio = strval($ci_aspect_ratio);
        }
    }
    $valeurs['aspect_ratio'] = $aspectRatio;

    // cas particulier du radius
    $radius_defaut = ciwidget_lire_meta_cle('graphique','point_radius');
    if (!isset($valeurs['point_radius'])){
        $valeurs['point_radius'] = $radius_defaut;
    }
    
    // cas particulier de la lineborderwidth
    $lineborderwidth_defaut = ciwidget_lire_meta_cle('graphique','lineborderwidth_defaut');
    if (!isset($valeurs['lineborderwidth_defaut'])){
        $valeurs['lineborderwidth_defaut'] = $lineborderwidth_defaut;
    }
    
    // cas particulier de ci_xaxes_lastlabelfontsize
    $valeurs['ci_xaxes_lastlabelfontsize'] = ciwidget_lire_meta_cle('graphique','ci_xaxes_lastlabelfontsize');
    
    
    // stacked ?
    if (isset($valeurs['type']) AND in_array($valeurs['type'],array('bar','horizontalBar')) 
            AND isset($valeurs['yAxes_stacked']) AND $valeurs['yAxes_stacked']=='true'){
        $valeurs['ci_stacked'] = 'oui';
    } else {    
        $valeurs['ci_stacked'] = 'non';
    }
    
    $valeurs['_yAxes_unite'] = $valeurs['yAxes_unite'];            
    
    $valeurs['retour_objet'] = ciwidget_retour_tmp_vers_objet($id_widget_tmp,$objet,$id_objet,$valeurs);
    $valeurs['ci_action'] = self('&', true);
        
    return $valeurs;
}

function formulaires_ciwidget_graphique8_verifier_dist($objet = '', $id_objet = '', $id_widget = 0, $id_widget_tmp = 0, $retour = '') {
        $erreurs = array();
        $champs_par_defaut = array_keys(ciwidget_graphique_config_par_defaut());
        $tableau_pourcentage1 = array(0, 25, 50, 75, 100, 125, 150, 175, 200, 225, 250, 300, 350, 400, 450, 500, 600, 700, 800);
        $tableau_pourcentage2 = array(100,95,90,85,80,75,70,65,60,55,50);

        foreach ($_POST as $nom_champ => $valeur) {
            if (_request($nom_champ)){

                if (in_array($nom_champ,array('yAxes_labelString'))){
                    $tableau_yAxes_labelString = array_map('trim',explode(PHP_EOL,_request($nom_champ)));
                    if (count($tableau_yAxes_labelString)>2){
                            $erreurs[$nom_champ] =  _T('ciwidget:valeur_incorrecte');
                    } else {
                        foreach ($tableau_yAxes_labelString AS $yAxes_labelString){
                            if (!ciwidget_verifier($nom_champ,$yAxes_labelString)){
                                $erreurs[$nom_champ] =  _T('ciwidget:valeur_incorrecte');
                            }
                        }
                    }
                } elseif (in_array($nom_champ,array('xAxes_labelString','yAxes_unite'))){
                    if (!ciwidget_verifier($nom_champ,_request($nom_champ))){
                        $erreurs[$nom_champ] =  _T('ciwidget:caracteres_autorises');
                    }
                } elseif (substr($nom_champ,0,13)=="couleur_serie"){
                    if (!ciwidget_verifier("couleur_serie",_request($nom_champ))){
                        $erreurs["couleur_serie"] =  _T('ciwidget:valeur_incorrecte');
                    }
                } elseif (substr($nom_champ,0,11)=="point_serie"){
                    if (!ciwidget_verifier("point_style",_request($nom_champ))){
                        $erreurs[$nom_champ] =  _T('ciwidget:valeur_incorrecte');
                    }
                } elseif (substr($nom_champ,0,12)=="radius_serie"){
                    if (!in_array(intval(_request($nom_champ)),$tableau_pourcentage1)){
                        $erreurs[$nom_champ] =  _T('ciwidget:valeur_incorrecte');
                    }
                } elseif (substr($nom_champ,0,14)=="showline_serie"){
                    if (!ciwidget_verifier("showline_style",_request($nom_champ))){
                        $erreurs[$nom_champ] =  _T('ciwidget:valeur_incorrecte');
                    }
                } elseif (substr($nom_champ,0,21)=="lineborderwidth_serie"){
                    if (!in_array(intval(_request($nom_champ)),$tableau_pourcentage1)){
                        $erreurs[$nom_champ] =  _T('ciwidget:valeur_incorrecte');
                    }
                } elseif (substr($nom_champ,0,19)=="lineborderdash_serie"){
                    if (_request($nom_champ)<0 OR _request($nom_champ)>10){
                        $erreurs[$nom_champ] =  _T('ciwidget:valeur_incorrecte');
                    }
                } elseif (substr($nom_champ,0,19)=="largeur_pourcentage"){
                    if (!in_array(intval(_request($nom_champ)),$tableau_pourcentage2)){
                        $erreurs[$nom_champ] =  _T('ciwidget:valeur_incorrecte');
                    }

                } elseif (in_array($nom_champ,$champs_par_defaut)){
                    if (!ciwidget_verifier($nom_champ,_request($nom_champ))){
                        $erreurs[$nom_champ] =  _T('ciwidget:valeur_incorrecte');
                    }
                }
            }
        }
        
	return $erreurs;
}

function formulaires_ciwidget_graphique8_traiter_dist($objet = '', $id_objet = '', $id_widget = 0, $id_widget_tmp = 0, $retour = '') {
        refuser_traiter_formulaire_ajax();    
    
        $type_widget = 'graphique';
        $c = array();
        $res = array();
                
        $contenu_nouveau = array();
        
        $tableau_champ_a_enlever = array('id_widget','id_widget_tmp','graphique_etape','precedent','form_precedent','graphique_image','numform','prerenseigner_config','modifier');
        
        foreach ($_POST as $cle => $valeur) {
            if (!in_array($cle,$tableau_champ_a_enlever) AND substr($cle,0,17)!="formulaire_action"){
                $contenu_nouveau[$cle] = _request($cle);
            }
        }

        $id_widget_tmp = ciwidget_maj_tmp($id_widget,$id_widget_tmp,$c,$contenu_nouveau);

        if (_request('precedent') OR _request('modifier')){
            $res = ciwidget_retour_formulaire_etape($objet,$id_objet,$id_widget,$id_widget_tmp,$type_widget,ciwidget_numform());
        } else {
            $res['message_ok'] = 'Ok';
            $res['redirect'] = ciwidget_retour_tmp_vers_objet($id_widget_tmp);
            
            // A mettre imperativement a la fin
            // Verser les donnees temporaires dans les donnees persistantes
            $id_widget = ciwidget_verser_tmp_dans_widget($id_widget_tmp,$type_widget);
            // memoriser l'image du graphique
            ciwidget_enregistrer_image($id_widget);
            ciwidget_enregistrer_csv($id_widget);
        }
        
	return $res;
}

function ciwidget_prerenseigner_config($id_widget_tmp=''){
    $tableau_valeurs = array();
    $return = '';
    $id_widget_tmp = intval($id_widget_tmp);
    $type = '';
    
    if ($id_widget_tmp > 0){
        // valeurs actuelles
        $valeurs = ciwidget_valeurs_tmp(0,$id_widget_tmp,'graphique');
        $type = ciwidget_graphique_type($valeurs);
    }
    
    // lister les widgets graphique de meme type
    if ($type AND ctype_alnum($type)){
        $result = sql_select("*", "spip_ciwidget", "type_widget='graphique'");
        while ($row = sql_fetch($result)) { 
            if (isset($row['contenu'])){
                $contenu = unserialize($row['contenu']);
                if (ciwidget_graphique_type($contenu)==$type){
                    $tableau_valeurs[$row['id_widget']] = $row['titre'];
                }
            }
        }

        // Parcours du tableau
        $return .= '<select id="prerenseigner_config" name="prerenseigner_config" style="width:80%;">'."\n";
        $return .= "\t".'<option value="0"></option>'."\n";
        foreach($tableau_valeurs as $valeur=>$libelle){
            // Affichage de la ligne
            $return .= "\t".'<option value="'. $valeur .'">'. $libelle .'</option>'."\n";
        }
        $return .= '</select>'."\n";
    }
    
    if (!$return){
        $return = "<div>"._T('avis_aucun_resultat')."</div>";
    } else {
        $return = '<label for="prerenseigner_config">'._T('ciwidget:prerenseigner_config').'</label>' . $return;
        if (spip_version()>=4) {
            $return .= '<button type="button" class="link" onclick="ci_prerenseigner_config();">'._T('bouton_choisir').'</button>';
        } else {
            $return .= '[<button type="button" class="link" onclick="ci_prerenseigner_config();">'._T('bouton_choisir').'</button>]';
        }
    }
    
    return $return;
}

?>